NetworkConnectivityBridge class
A singleton bridge around connectivity_plus to provide global access to connectivity status and allow multiple listeners to subscribe without conflict.
Properties
-
currentStatus
→ List<
ConnectivityResult> ? -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onConnectivityChanged
→ Stream<
List< ConnectivityResult> > -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
initialize(
) → Future< void> - Initialize connectivity bridge. Should be called once at app startup.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → NetworkConnectivityBridge
-
final